@@ -2,22 +2,23 @@
 
 import os
 from os.path import join as joinp
-import nose.tools as nt
-from nose.plugins.attrib import attr
+
+import pytest
+import numpy
 
 from bluepyopt.ephys import efeatures
 from bluepyopt.ephys.responses import TimeVoltageResponse
 from bluepyopt.ephys.serializer import instantiator
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_EFeature():
     """ephys.efeatures: Testing EFeature creation"""
     efeature = efeatures.EFeature('name')
-    nt.eq_(efeature.name, 'name')
+    assert efeature.name == 'name'
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_eFELFeature():
     """ephys.efeatures: Testing eFELFeature creation"""
     recording_names = {'': 'square_pulse_step1.soma.v'}
@@ -38,16 +39,16 @@ def test_eFELFeature():
     responses = {'square_pulse_step1.soma.v': response, }
 
     ret = efeature.calculate_feature(responses, raise_warnings=True)
-    nt.assert_almost_equal(ret, -72.05761247316858)
+    numpy.testing.assert_almost_equal(ret, -72.05761247316858)
 
     score = efeature.calculate_score(responses)
-    nt.assert_almost_equal(score, 73.05761247316858)
+    numpy.testing.assert_almost_equal(score, 73.05761247316858)
 
-    nt.eq_(efeature.name, 'test_eFELFeature')
-    nt.ok_('voltage_base' in str(efeature))
+    assert efeature.name == 'test_eFELFeature'
+    assert 'voltage_base' in str(efeature)
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_eFELFeature_max_score():
     """ephys.efeatures: Testing eFELFeature max_score option"""
 
@@ -69,7 +70,7 @@ def test_eFELFeature_max_score():
                                             exp_mean=1,
                                             exp_std=1)
     score_normal = efeature_normal.calculate_score(responses)
-    nt.assert_almost_equal(score_normal, 250)
+    numpy.testing.assert_almost_equal(score_normal, 250)
 
     efeature_150 = efeatures.eFELFeature(name='test_eFELFeature',
                                          efel_feature_name='AP_amplitude',
@@ -81,10 +82,10 @@ def test_eFELFeature_max_score():
                                          max_score=150)
 
     score_150 = efeature_150.calculate_score(responses)
-    nt.assert_almost_equal(score_150, 150)
+    numpy.testing.assert_almost_equal(score_150, 150)
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_eFELFeature_force_max_score():
     """ephys.efeatures: Testing eFELFeature force_max_score option"""
 
@@ -106,7 +107,7 @@ def test_eFELFeature_force_max_score():
                                             exp_mean=1,
                                             exp_std=.001)
     score_normal = efeature_normal.calculate_score(responses)
-    nt.assert_true(score_normal > 250)
+    assert score_normal > 250
 
     efeature_force = efeatures.eFELFeature(name='test_eFELFeature',
                                            efel_feature_name='voltage_base',
@@ -118,10 +119,10 @@ def test_eFELFeature_force_max_score():
                                            force_max_score=True)
 
     score_force = efeature_force.calculate_score(responses)
-    nt.assert_almost_equal(score_force, 250)
+    numpy.testing.assert_almost_equal(score_force, 250)
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_eFELFeature_double_settings():
     """ephys.efeatures: Testing eFELFeature double_settings"""
     recording_names = {'': 'square_pulse_step1.soma.v'}
@@ -156,10 +157,10 @@ def test_eFELFeature_double_settings():
         raise_warnings=True)
     vb = efeature.calculate_feature(responses, raise_warnings=True)
 
-    nt.assert_true(vb_other_perc != vb)
+    assert vb_other_perc != vb
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_eFELFeature_int_settings():
     """ephys.efeatures: Testing eFELFeature int_settings"""
     recording_names = {'': 'square_pulse_step1.soma.v'}
@@ -192,10 +193,10 @@ def test_eFELFeature_int_settings():
     spikecount = efeature.calculate_feature(responses)
     spikecount_strict = efeature_strict.calculate_feature(responses)
 
-    nt.assert_true(spikecount_strict != spikecount)
+    assert spikecount_strict != spikecount
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_eFELFeature_string_settings():
     """ephys.efeatures: Testing eFELFeature string_settings"""
     recording_names = {'': 'square_pulse_step1.soma.v'}
@@ -226,10 +227,10 @@ def test_eFELFeature_string_settings():
         raise_warnings=True)
     vb_default = efeature.calculate_feature(responses, raise_warnings=True)
 
-    nt.assert_true(vb_median != vb_default)
+    assert vb_median != vb_default
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_eFELFeature_serialize():
     """ephys.efeatures: Testing eFELFeature serialization"""
     recording_names = {'': 'square_pulse_step1.soma.v'}
@@ -242,6 +243,6 @@ def test_eFELFeature_serialize():
                                      exp_std=1)
     serialized = efeature.to_dict()
     deserialized = instantiator(serialized)
-    nt.ok_(isinstance(deserialized, efeatures.eFELFeature))
-    nt.eq_(deserialized.stim_start, 700)
-    nt.eq_(deserialized.recording_names, recording_names)
+    assert isinstance(deserialized, efeatures.eFELFeature)
+    assert deserialized.stim_start == 700
+    assert deserialized.recording_names == recording_names
