@@ -21,20 +21,21 @@ Copyright (c) 2016-2020, EPFL/Blue Brain Project
 
 # pylint:disable=W0612
 
-import nose.tools as nt
-from nose.plugins.attrib import attr
+
+import pytest
+import numpy
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_import():
     """ephys: test importing bluepyopt.ephys"""
     import bluepyopt.ephys  # NOQA
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_ephys_base():
     """ephys: test ephys base class"""
     import bluepyopt.ephys as ephys
     base = ephys.base.BaseEPhys(name='test', comment='comm')
 
-    nt.assert_equal(str(base), 'BaseEPhys: test (comm)')
+    assert str(base) == 'BaseEPhys: test (comm)'
